==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageSwiftFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryConfigStorageSwiftFluent<A extends ImageRegistryConfigStorageSwiftFluent<A>> extends BaseFluent<A>{
  public ImageRegistryConfigStorageSwiftFluent() {
  }
  
  public ImageRegistryConfigStorageSwiftFluent(ImageRegistryConfigStorageSwift instance) {
    this.copyInstance(instance);
  }
  private String authURL;
  private String authVersion;
  private String container;
  private String domain;
  private String domainID;
  private String regionName;
  private String tenant;
  private String tenantID;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryConfigStorageSwift instance) {
    instance = (instance != null ? instance : new ImageRegistryConfigStorageSwift());
  
    if (instance != null) {
        this.withAuthURL(instance.getAuthURL());
        this.withAuthVersion(instance.getAuthVersion());
        this.withContainer(instance.getContainer());
        this.withDomain(instance.getDomain());
        this.withDomainID(instance.getDomainID());
        this.withRegionName(instance.getRegionName());
        this.withTenant(instance.getTenant());
        this.withTenantID(instance.getTenantID());
        this.withAuthURL(instance.getAuthURL());
        this.withAuthVersion(instance.getAuthVersion());
        this.withContainer(instance.getContainer());
        this.withDomain(instance.getDomain());
        this.withDomainID(instance.getDomainID());
        this.withRegionName(instance.getRegionName());
        this.withTenant(instance.getTenant());
        this.withTenantID(instance.getTenantID());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getAuthURL() {
    return this.authURL;
  }
  
  public A withAuthURL(String authURL) {
    this.authURL=authURL; return (A) this;
  }
  
  public boolean hasAuthURL() {
    return this.authURL != null;
  }
  
  public String getAuthVersion() {
    return this.authVersion;
  }
  
  public A withAuthVersion(String authVersion) {
    this.authVersion=authVersion; return (A) this;
  }
  
  public boolean hasAuthVersion() {
    return this.authVersion != null;
  }
  
  public String getContainer() {
    return this.container;
  }
  
  public A withContainer(String container) {
    this.container=container; return (A) this;
  }
  
  public boolean hasContainer() {
    return this.container != null;
  }
  
  public String getDomain() {
    return this.domain;
  }
  
  public A withDomain(String domain) {
    this.domain=domain; return (A) this;
  }
  
  public boolean hasDomain() {
    return this.domain != null;
  }
  
  public String getDomainID() {
    return this.domainID;
  }
  
  public A withDomainID(String domainID) {
    this.domainID=domainID; return (A) this;
  }
  
  public boolean hasDomainID() {
    return this.domainID != null;
  }
  
  public String getRegionName() {
    return this.regionName;
  }
  
  public A withRegionName(String regionName) {
    this.regionName=regionName; return (A) this;
  }
  
  public boolean hasRegionName() {
    return this.regionName != null;
  }
  
  public String getTenant() {
    return this.tenant;
  }
  
  public A withTenant(String tenant) {
    this.tenant=tenant; return (A) this;
  }
  
  public boolean hasTenant() {
    return this.tenant != null;
  }
  
  public String getTenantID() {
    return this.tenantID;
  }
  
  public A withTenantID(String tenantID) {
    this.tenantID=tenantID; return (A) this;
  }
  
  public boolean hasTenantID() {
    return this.tenantID != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageSwiftFluent that = (ImageRegistryConfigStorageSwiftFluent) o;
    if (!java.util.Objects.equals(authURL, that.authURL)) return false;
  
    if (!java.util.Objects.equals(authVersion, that.authVersion)) return false;
  
    if (!java.util.Objects.equals(container, that.container)) return false;
  
    if (!java.util.Objects.equals(domain, that.domain)) return false;
  
    if (!java.util.Objects.equals(domainID, that.domainID)) return false;
  
    if (!java.util.Objects.equals(regionName, that.regionName)) return false;
  
    if (!java.util.Objects.equals(tenant, that.tenant)) return false;
  
    if (!java.util.Objects.equals(tenantID, that.tenantID)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(authURL,  authVersion,  container,  domain,  domainID,  regionName,  tenant,  tenantID,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authURL != null) { sb.append("authURL:"); sb.append(authURL + ","); }
    if (authVersion != null) { sb.append("authVersion:"); sb.append(authVersion + ","); }
    if (container != null) { sb.append("container:"); sb.append(container + ","); }
    if (domain != null) { sb.append("domain:"); sb.append(domain + ","); }
    if (domainID != null) { sb.append("domainID:"); sb.append(domainID + ","); }
    if (regionName != null) { sb.append("regionName:"); sb.append(regionName + ","); }
    if (tenant != null) { sb.append("tenant:"); sb.append(tenant + ","); }
    if (tenantID != null) { sb.append("tenantID:"); sb.append(tenantID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-miscellaneous-6.9.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageSwiftFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryConfigStorageSwiftFluent<A extends ImageRegistryConfigStorageSwiftFluent<A>> extends BaseFluent<A>{
  public ImageRegistryConfigStorageSwiftFluent() {
  }
  
  public ImageRegistryConfigStorageSwiftFluent(ImageRegistryConfigStorageSwift instance) {
    this.copyInstance(instance);
  }
  private String authURL;
  private String authVersion;
  private String container;
  private String domain;
  private String domainID;
  private String regionName;
  private String tenant;
  private String tenantID;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryConfigStorageSwift instance) {
    instance = (instance != null ? instance : new ImageRegistryConfigStorageSwift());
    if (instance != null) {
          this.withAuthURL(instance.getAuthURL());
          this.withAuthVersion(instance.getAuthVersion());
          this.withContainer(instance.getContainer());
          this.withDomain(instance.getDomain());
          this.withDomainID(instance.getDomainID());
          this.withRegionName(instance.getRegionName());
          this.withTenant(instance.getTenant());
          this.withTenantID(instance.getTenantID());
          this.withAuthURL(instance.getAuthURL());
          this.withAuthVersion(instance.getAuthVersion());
          this.withContainer(instance.getContainer());
          this.withDomain(instance.getDomain());
          this.withDomainID(instance.getDomainID());
          this.withRegionName(instance.getRegionName());
          this.withTenant(instance.getTenant());
          this.withTenantID(instance.getTenantID());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAuthURL() {
    return this.authURL;
  }
  
  public A withAuthURL(String authURL) {
    this.authURL = authURL;
    return (A) this;
  }
  
  public boolean hasAuthURL() {
    return this.authURL != null;
  }
  
  public String getAuthVersion() {
    return this.authVersion;
  }
  
  public A withAuthVersion(String authVersion) {
    this.authVersion = authVersion;
    return (A) this;
  }
  
  public boolean hasAuthVersion() {
    return this.authVersion != null;
  }
  
  public String getContainer() {
    return this.container;
  }
  
  public A withContainer(String container) {
    this.container = container;
    return (A) this;
  }
  
  public boolean hasContainer() {
    return this.container != null;
  }
  
  public String getDomain() {
    return this.domain;
  }
  
  public A withDomain(String domain) {
    this.domain = domain;
    return (A) this;
  }
  
  public boolean hasDomain() {
    return this.domain != null;
  }
  
  public String getDomainID() {
    return this.domainID;
  }
  
  public A withDomainID(String domainID) {
    this.domainID = domainID;
    return (A) this;
  }
  
  public boolean hasDomainID() {
    return this.domainID != null;
  }
  
  public String getRegionName() {
    return this.regionName;
  }
  
  public A withRegionName(String regionName) {
    this.regionName = regionName;
    return (A) this;
  }
  
  public boolean hasRegionName() {
    return this.regionName != null;
  }
  
  public String getTenant() {
    return this.tenant;
  }
  
  public A withTenant(String tenant) {
    this.tenant = tenant;
    return (A) this;
  }
  
  public boolean hasTenant() {
    return this.tenant != null;
  }
  
  public String getTenantID() {
    return this.tenantID;
  }
  
  public A withTenantID(String tenantID) {
    this.tenantID = tenantID;
    return (A) this;
  }
  
  public boolean hasTenantID() {
    return this.tenantID != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageSwiftFluent that = (ImageRegistryConfigStorageSwiftFluent) o;
    if (!java.util.Objects.equals(authURL, that.authURL)) return false;
    if (!java.util.Objects.equals(authVersion, that.authVersion)) return false;
    if (!java.util.Objects.equals(container, that.container)) return false;
    if (!java.util.Objects.equals(domain, that.domain)) return false;
    if (!java.util.Objects.equals(domainID, that.domainID)) return false;
    if (!java.util.Objects.equals(regionName, that.regionName)) return false;
    if (!java.util.Objects.equals(tenant, that.tenant)) return false;
    if (!java.util.Objects.equals(tenantID, that.tenantID)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(authURL,  authVersion,  container,  domain,  domainID,  regionName,  tenant,  tenantID,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authURL != null) { sb.append("authURL:"); sb.append(authURL + ","); }
    if (authVersion != null) { sb.append("authVersion:"); sb.append(authVersion + ","); }
    if (container != null) { sb.append("container:"); sb.append(container + ","); }
    if (domain != null) { sb.append("domain:"); sb.append(domain + ","); }
    if (domainID != null) { sb.append("domainID:"); sb.append(domainID + ","); }
    if (regionName != null) { sb.append("regionName:"); sb.append(regionName + ","); }
    if (tenant != null) { sb.append("tenant:"); sb.append(tenant + ","); }
    if (tenantID != null) { sb.append("tenantID:"); sb.append(tenantID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
